##  Permissions
User Role | Permissions for KPIs
---|---
Admin |  Create, update, and delete KPIs. Admins can grant these permissions to non-admin roles in the User Roles and Permissions section of the administration area. For details, see [User Roles and Permissions](https://help.sap.com/docs/leanix/ea/user-roles-and-permissions?locale=en-US&state=PRODUCTION&version=CLOUD "Adjust role-based permissions and define custom roles.").
All roles |  Add KPIs to dashboards for which the user has permissions. If a user role doesn't have permissions for a specific fact sheet type or fact sheet field involved in KPI calculations, they cannot access that KPI. To learn more about roles, see [User Roles and Permissions](https://help.sap.com/docs/leanix/ea/user-roles-and-permissions?locale=en-US&state=PRODUCTION&version=CLOUD "Adjust role-based permissions and define custom roles.").


